sqltriples.Query.CombinedTopLevelResults

Package sqltriples :: Module Query :: Class CombinedTopLevelResults |
[show private | hide private]
[frames | no frames]

## Class CombinedTopLevelResults

    CombinedResults --+
                      |
                     CombinedTopLevelResults

Known Subclasses:
  `Intersection`

Method Summary
| `get_query(self, index)`
| `get_subquery(self, parent_columns, parent_index, index, match_first, match_parent, match_child)`

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net